package polling_station_dashboard.java;

import javafx.fxml.FXMLLoader;
import javafx.scene.Parent;
import javafx.scene.Scene;
import javafx.stage.Stage;
import polling_station_dashboard.settings.java.SettingsVisualUpdater;
import polling_station_dashboard.statusLog.java.StatusLogLoader;
import polling_station_dashboard.settings.java.settingsLoader;
import polling_station_dashboard.statusLog.java.StatusLogVisualUpdater;

import java.io.IOException;

/**
 * Created by Vladimir Eliezer Tokarev on 28/05/2016
 * This class loads the polling station fxml
 */
public class PollingStationDashboardLoader {

    private static final String POLLING_STATION_DASHBOARD_FXML_PATH = "../fxml/polling_station_dashboard.fxml";

    private Stage currentStage;

    public PollingStationDashboardLoader (Stage primaryStage) throws IOException
    {
        primaryStage.setX(100);
        primaryStage.setY(100);

        currentStage = primaryStage;
        FXMLLoader fxmlLoader = new FXMLLoader(getClass().getResource(POLLING_STATION_DASHBOARD_FXML_PATH));
        Parent root = fxmlLoader.load();
        PollingStationDashboardController controller = fxmlLoader.getController();

        currentStage.setTitle("Polling Station Dashboard");
        currentStage.setScene(new Scene(root, 850, 615));
        currentStage.show();

        controller.SetStage(currentStage);
        setSettingsUpdater(controller);
        setStatusLogUpdater(controller);

    }

    private void setSettingsUpdater(PollingStationDashboardController controller) throws IOException
    {
        settingsLoader settingsLoader = new settingsLoader(currentStage);
        SettingsVisualUpdater settingsVisualUpdater =
                new SettingsVisualUpdater(settingsLoader.GetSettingsInstance(), currentStage);
        controller.SetSettingsVisualUpdater(settingsVisualUpdater);
    }

    private void setStatusLogUpdater(PollingStationDashboardController controller) throws  IOException
    {
        StatusLogLoader statusLogLoader = new StatusLogLoader(currentStage);
        StatusLogVisualUpdater statusLogVisualUpdater =
                new StatusLogVisualUpdater(statusLogLoader.GetStatusLogInstance(), currentStage);
        controller.SetStatusLogVisualUpdater(statusLogVisualUpdater);
    }
}
